@@ -11,15 +11,16 @@ log = logging.getLogger(__name__)
 
 class InMemPropertiesServiceClient(IPropertiesServiceClient):
     """
-    Impelmentation of IProperties that are kept only in memory.
+    Implementation of IProperties that are kept only in memory.
     """
 
     def __init__(self):
         self._props = {}
 
-    def read_properties(self, job_name: str) -> Dict:
+    def read_properties(self, job_name: str, team_name: str) -> Dict:
         res = deepcopy(self._props)
         return res
 
-    def write_properties(self, job_name: str, properties: Dict) -> None:
+    def write_properties(self, job_name: str, team_name: str, properties: Dict) -> Dict:
         self._props = deepcopy(properties)
+        return self._props
